==> libreoffice_5.1.2.orig.tar.xz: libreoffice-5.1.2/sfx2/source/notify/hintpost.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <sfx2/hintpost.hxx>

#include "arrdecl.hxx"
#include <sfx2/app.hxx>
#include "sfxtypes.hxx"


SfxHintPoster::SfxHintPoster(const Link<SfxRequest*,void>& rLink)
    : m_Link(rLink)
{
}

SfxHintPoster::~SfxHintPoster()
{
}

void SfxHintPoster::Post( SfxRequest* pHintToPost )
{
    Application::PostUserEvent( ( LINK(this, SfxHintPoster, DoEvent_Impl) ), pHintToPost );
    AddFirstRef();
}

IMPL_LINK_TYPED( SfxHintPoster, DoEvent_Impl, void *, pPostedHint, void )
{
    m_Link.Call( static_cast<SfxRequest*>(pPostedHint) );
    ReleaseRef();
}

void SfxHintPoster::SetEventHdl(const Link<SfxRequest*,void>& rLink)
{
    m_Link = rLink;
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-5.4.6.2.tar.xz: libreoffice-5.4.6.2/sfx2/source/notify/hintpost.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <sfx2/hintpost.hxx>

#include "arrdecl.hxx"
#include <sfx2/app.hxx>
#include "sfxtypes.hxx"


SfxHintPoster::SfxHintPoster(const Link<SfxRequest*,void>& rLink)
    : m_Link(rLink)
{
}

SfxHintPoster::~SfxHintPoster()
{
}

void SfxHintPoster::Post( SfxRequest* pHintToPost )
{
    Application::PostUserEvent( ( LINK(this, SfxHintPoster, DoEvent_Impl) ), pHintToPost );
    AddFirstRef();
}

IMPL_LINK( SfxHintPoster, DoEvent_Impl, void *, pPostedHint, void )
{
    m_Link.Call( static_cast<SfxRequest*>(pPostedHint) );
    ReleaseRef();
}

void SfxHintPoster::SetEventHdl(const Link<SfxRequest*,void>& rLink)
{
    m_Link = rLink;
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
